@@ -1,9 +1,10 @@
 package Dist::Zilla::Plugin::SchwartzRatio;
 our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: display the Schwartz ratio of the distribution upon release
-$Dist::Zilla::Plugin::SchwartzRatio::VERSION = '0.3.1';
+$Dist::Zilla::Plugin::SchwartzRatio::VERSION = '0.3.2';
 
-use 5.22.0;
+use 5.14.0;
+use strict;
 use warnings;
 
 use List::UtilsBy qw/ sort_by /;
@@ -16,8 +17,6 @@ with qw/
     Dist::Zilla::Role::AfterRelease
 /;
 
-use experimental 'signatures';
-
 has mcpan => (
     is      => 'ro',
     lazy    => 1,
@@ -32,7 +31,8 @@ has releases => (
         nbr_releases => 'count',
     },
     lazy => 1,
-    default => sub($self) {
+    default => sub {
+        my $self = shift;
         
         my $releases = $self->mcpan->release({
             distribution => $self->zilla->name
@@ -49,7 +49,8 @@ has releases => (
     },
 );
 
-sub after_release($self,@) {
+sub after_release {
+    my $self = shift;
 
     $self->log( $self->nbr_releases . " old releases are lingering on CPAN" );
     $self->log( "\t" . join ', ', @$_ ) for $self->all_releases;
@@ -71,7 +72,7 @@ Dist::Zilla::Plugin::SchwartzRatio - display the Schwartz ratio of the distribut
 
 =head1 VERSION
 
-version 0.3.1
+version 0.3.2
 
 =head1 SYNOPSIS
 
